/****************************************************************************
 * fs/driver/fs_unregisterpipedriver.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <nuttx/fs/fs.h>

#include "inode/inode.h"
#include "notify/notify.h"

#ifdef CONFIG_PIPES

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: unregister_pipedriver
 *
 * Description:
 *   Remove the pipe driver inode at 'path' from the pseudo-file system
 *
 ****************************************************************************/

int unregister_pipedriver(FAR const char *path)
{
  int ret;

  ret = inode_lock();
  if (ret >= 0)
    {
      ret = inode_remove(path);
      inode_unlock();
#ifdef CONFIG_FS_NOTIFY
      notify_unlink(path);
#endif
      return OK;
    }

  inode_unlock();
  return ret;
}

#endif /* CONFIG_PIPES */
